<?php

/**
 * @file
 * Administration functions for the domain meta module.
 *
 */

 /**
 * Assign domain based meta tags
 *
 */
function domain_meta_page($domain) {
  // Ensure we are on the proper domain.
  domain_goto($domain);
  drupal_set_title(t('!site : Domain meta tag settings', array('!site' => $domain['sitename'])));
  $output = theme_domain_meta_reset($domain);
  return $output . drupal_get_form('domain_meta_settings_form');
}

/**
 * Resets locale settings by setting them to default domain settings in {domain_locale}.
 *
 * @param $domain
 * The $domain object created by domain_lookup().
 * @return
 * A confirmation form.
 */
function domain_meta_reset($domain) {
  if ($domain == 0) {
    return t('An invalid request has been made.');
  }
  return drupal_get_form('domain_meta_reset_form', $domain);
}

/**
 * FormsAPI for resetting domain meta tags.
 *
 * @param $domain
 * The $domain object for the selected domain.
 * @return
 * Themed HTML form.
 */
function domain_meta_reset_form($form_state, $domain) {
  $extra['domain_id'] = array('#type' => 'value', '#value' => $domain['domain_id']);
  $form = confirm_form($extra, t('Are you sure you wish to reset meta tags for %name?', array('%name' => $domain['sitename'])), 'admin/build/domain/meta/'. $domain['domain_id'], t('Submitting this form will remove domain specific meta tags from this domain.'));
  return $form;
}

/**
 * FormsAPI for domain_locale_reset_form.
 */
function domain_meta_reset_form_submit($form, &$form_state) {
  $meta_tags = array('domain_meta_keywords', 'domain_meta_description');
  foreach ($meta_tags as $tag) {
    domain_conf_variable_set($domain['domain_id'], $tag, '');
  }
  cache_clear_all('variables', 'cache');
  drupal_set_message(t('Domain meta tag settings have been reset to default domain settings.'));
  $form_state['redirect'] = 'admin/build/domain/meta/'. $form_state['values']['domain_id'];
}